@@ -190,10 +190,6 @@ void ActionManager::createCalendarAkonadi()
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     mCollectionSelectionModelStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group(QStringLiteral("GlobalCollectionSelection")));
     mCollectionSelectionModelStateSaver->setSelectionModel(calendar()->checkableProxyModel()->selectionModel());
-    connect(calendar()->checkableProxyModel()->selectionModel(),
-            &QItemSelectionModel::selectionChanged,
-            mCollectionSelectionModelStateSaver,
-            &KViewStateMaintainer<Akonadi::ETMViewStateSaver>::saveState);
 
     AkonadiCollectionViewFactory factory(mCalendarView);
     mCalendarView->addExtension(&factory);
@@ -915,7 +911,7 @@ void ActionManager::writeSettings()
 void ActionManager::file_open()
 {
     const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1String("/korganizer/"));
+    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1StringView("/korganizer/"));
     const QUrl url =
         QFileDialog::getOpenFileUrl(dialogParent(), i18nc("@title:window", "Select Calendar File to Open"), dir, QStringLiteral("text/calendar (*.ics *.vcs)"));
 
@@ -943,7 +939,7 @@ void ActionManager::file_open(const QUrl &url)
 void ActionManager::file_import()
 {
     const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1String("/korganizer/"));
+    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1StringView("/korganizer/"));
     const QUrl url = QFileDialog::getOpenFileUrl(dialogParent(),
                                                  i18nc("@title:window", "Select Calendar File to Import"),
                                                  dir,
@@ -1113,7 +1109,7 @@ void ActionManager::dumpText(const QString &str)
 
 void ActionManager::toggleDateNavigator()
 {
-    bool visible = mDateNavigatorShowAction->isChecked();
+    const bool visible = mDateNavigatorShowAction->isChecked();
     if (mCalendarView) {
         mCalendarView->showDateNavigator(visible);
     }
@@ -1121,7 +1117,7 @@ void ActionManager::toggleDateNavigator()
 
 void ActionManager::toggleTodoView()
 {
-    bool visible = mTodoViewShowAction->isChecked();
+    const bool visible = mTodoViewShowAction->isChecked();
     if (mCalendarView) {
         mCalendarView->showTodoView(visible);
     }
@@ -1129,7 +1125,7 @@ void ActionManager::toggleTodoView()
 
 void ActionManager::toggleEventViewer()
 {
-    bool visible = mEventViewerShowAction->isChecked();
+    const bool visible = mEventViewerShowAction->isChecked();
     if (mCalendarView) {
         mCalendarView->showEventViewer(visible);
     }
@@ -1414,7 +1410,7 @@ void ActionManager::openEventEditor(const QString &summary,
                                     const QString &attachmentMimetype)
 {
     int action = IncidenceEditorNG::IncidenceEditorSettings::self()->defaultEmailAttachMethod();
-    if (attachmentMimetype != QLatin1String("message/rfc822")) {
+    if (attachmentMimetype != QLatin1StringView("message/rfc822")) {
         action = IncidenceEditorNG::IncidenceEditorSettings::Link;
     } else if (file.isEmpty()) {
         action = KOPrefs::TodoAttachLink;
@@ -1520,7 +1516,7 @@ void ActionManager::openTodoEditor(const QString &summary,
                                    const QString &attachmentMimetype)
 {
     int action = KOPrefs::instance()->defaultTodoAttachMethod();
-    if (attachmentMimetype != QLatin1String("message/rfc822")) {
+    if (attachmentMimetype != QLatin1StringView("message/rfc822")) {
         action = KOPrefs::TodoAttachLink;
     } else if (file.isEmpty()) {
         action = KOPrefs::TodoAttachLink;
