@@ -19,6 +19,7 @@
 
 #include <Akonadi/ManageAccountWidget>
 #include <IncidenceEditor/IncidenceEditorSettings>
+#include <akonadi/calendarsettings.h>
 
 #include <KLocalizedString>
 #include <QCheckBox>
@@ -30,7 +31,9 @@ KOPrefsDialogMain::KOPrefsDialogMain(QObject *parent, const KPluginMetaData &dat
     : Korganizer::KPrefsModule(KOPrefs::instance(), parent, data)
 {
     auto topTopLayout = new QVBoxLayout(widget());
+    topTopLayout->setContentsMargins({});
     auto tabWidget = new QTabWidget(widget());
+    tabWidget->setDocumentMode(true);
     topTopLayout->addWidget(tabWidget);
 
     // Personal Settings
@@ -55,6 +58,12 @@ KOPrefsDialogMain::KOPrefsDialogMain(QObject *parent, const KPluginMetaData &dat
     Korganizer::KPrefsWidRadios *defaultEmailAttachMethod =
         addWidRadios(IncidenceEditorNG::IncidenceEditorSettings::self()->defaultEmailAttachMethodItem(), personalFrame);
     personalLayout->addWidget(defaultEmailAttachMethod->groupBox());
+
+    auto remindersGroup = new QGroupBox(i18nc("@title:group", "Reminders"), personalFrame);
+    auto remindersLayout = new QFormLayout(remindersGroup);
+    Korganizer::KPrefsWidBool *onlyMyReminders = addWidBool(Akonadi::CalendarSettings::self()->onlyShowRemindersForMyEventsItem(), remindersGroup);
+    remindersLayout->addWidget(onlyMyReminders->checkBox());
+    personalLayout->addWidget(remindersGroup);
     personalLayout->addStretch(1);
 
     // Save Settings
